/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/*
 * Папраўце гэты файл і захавайце яго як userContent.css у
 * дырэкторыі chrome/ вашага профілю.
 */

/*
 * Гэты файл можа ўжывацца для надання стылю ўсім старонкам Сеціва,
 * якія вы праглядаеце.
 * Правілы без !important перавызначаюцца правіламі аўтара, калі ён
 * прызначыў іх. Правілы з !important замяняюць правілы аўтара.
 */

/*
 * прыклад: выключыць мігаценне адзінкі "blink"
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * прыклад: прызначыць мяжу ў 2 пікселі усім табліцам
 *
 * table { border: 2px solid; }
 */

/*
 * прыклад: выключыць адзінку "marquee"
 *
 * marquee { -moz-binding: none; }
 *
 */
 
/* 
 * Наведайце http://www.mozilla.org/unix/customizing.html каб атрымаць больш прыкладаў.
 */

